// $Id: arraygeometry.hpp,v 1.2 2005/02/25 12:22:16 grosskur Exp $
//
// Copyright (C) 2003 Alan Grosskurth
//
// This file is part of Spatter.
//
// Spatter is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2 of the License, or
// (at your option) any later version.
//
// Spatter is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
// General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with Spatter; if not, write to the Free Software Foundation,
// Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA

#ifndef INCLUDED_ARRAYGEOMETRY_HPP
#define INCLUDED_ARRAYGEOMETRY_HPP

#include <fstream>
#include <ltiPoint.h>

struct ArrayGeometry {
    ArrayGeometry();
    ArrayGeometry(std::istream& in);

    void load(std::istream& in);

    lti::ipoint size;
    lti::dpoint delta;
    lti::ipoint subgrid_size;
    lti::dpoint subgrid_delta;
};

#endif // INCLUDED_ARRAYGEOMETRY_HPP
